Please see [https://docs.mlcommons.org/cm4mlops/scripts/Reproduce-MLPerf-benchmarks/reproduce-mlperf-octoml-tinyml-results](https://docs.mlcommons.org/cm4mlops/scripts/Reproduce-MLPerf-benchmarks/reproduce-mlperf-octoml-tinyml-results) for the documentation of this CM script.
